# Python-discord-rankcard

![img](https://github.com/yangman946/Python-discord-rankcard/blob/main/Rankcard/pics/out.jpg)


## Usage
```

  self.rankcard = RANKCARD()
  card = self.rankcard.rank_card(
                      username="Username", # user name
                      avatar="https://cdn.discordapp.com/embed/avatars/0.png", # user avatar (e.g., ctx.author.avatar_url)
                      level=1, # user level
                      rank=1, # user rank
                      current_xp=0, # user xp
                      custom_background= "#000000", # background colour
                      xp_color="#FF7A7A", # Foreground colour
                      next_level_xp=100) # Next level xp


```



